@@ -4,7 +4,7 @@ use utf8;
 use warnings;
 use strict;
 
-$Text::Morse::VERSION = '0.06';
+$Text::Morse::VERSION = '0.07';
 
 no warnings 'qw';
 
@@ -211,11 +211,11 @@ universal high ASCII (UNIX or Windows, not DOS) :-)
 
 	Bug tracking for this module: https://rt.cpan.org/Dist/Display.html?Name=Text-Morse
 
-	Source hosting: http://www.github.com/bennie/perl-VMware-vCloud
+	Source hosting: http://www.github.com/bennie/perl-Text-Morse
 
 =head1 VERSION
 
-	Text::Morse v0.06 (2015/06/09)
+	Text::Morse v0.07 (2015/06/09)
 
 =head1 COPYRIGHT
 
